scoretemplatetools.ScoreTemplate
================================

.. abjad-lineage:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate

.. autoclass:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__call__
   :noindex:

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__ge__
   :noindex:

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__gt__
   :noindex:

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__le__
   :noindex:

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__lt__
   :noindex:

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__repr__
   :noindex:
